@@ -8,11 +8,8 @@ from oasys.widgets import gui as oasysgui, congruence
 from oasys.widgets.exchange import DataExchangeObject
 from orangecontrib.xoppy.widgets.gui.ow_xoppy_widget import XoppyWidget
 
-
 import scipy.constants as codata
 
-
-
 from crystalpy.diffraction.GeometryType import BraggDiffraction, LaueDiffraction
 from crystalpy.diffraction.DiffractionSetup import DiffractionSetup
 from crystalpy.diffraction.Diffraction import Diffraction
@@ -101,10 +98,6 @@ class Monochromator(XoppyWidget):
         gui.button(file_box_id, self, "...", callback=self.select_input_file, width=25)
         self.show_at(self.unitFlags()[idx], box1)
 
-
-
-
-
         box = oasysgui.widgetBox(box_main, "Monochromator", orientation="vertical", width=self.CONTROL_AREA_WIDTH-10)
         # widget index 2
         idx += 1
@@ -147,8 +140,6 @@ class Monochromator(XoppyWidget):
                           valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
-
-
         # widget index 5
         idx += 1
         box1 = gui.widgetBox(box)
@@ -157,7 +148,6 @@ class Monochromator(XoppyWidget):
                                        valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
-
         #widget index 10
         idx += 1
         box1 = gui.widgetBox(box)
@@ -172,8 +162,6 @@ class Monochromator(XoppyWidget):
         self.input_spectrum = None
 
 
-
-
     def select_input_file(self):
         self.file_id.setText(oasysgui.selectFileFromDialog(self, self.SOURCE_FILE,
                                     "Open 2-columns file with spectral power",
@@ -300,8 +288,6 @@ class Monochromator(XoppyWidget):
             #raise exception
 
 
-
-
     def check_fields(self):
         if self.TYPE  ==  1:
             self.ENER_SELECTED = congruence.checkPositiveNumber(self.ENER_SELECTED, "Energy Selected [eV]")
@@ -331,13 +317,9 @@ class Monochromator(XoppyWidget):
     def extract_data_from_xoppy_output(self, calculation_output):
         return calculation_output
 
-
     def get_data_exchange_widget_name(self):
         return "POWER"
 
-
-
-
     def getTitles(self):
         return ['Input Beam','Monochromator reflectivity','Transmitted intensity']
 
@@ -473,8 +455,8 @@ class Monochromator(XoppyWidget):
                                             harmonic*h_miller, harmonic*k_miller, harmonic*l_miller))
 
         return r
-    def xoppy_calc_mono(self):
 
+    def xoppy_calc_mono(self):
 
         if self.SOURCE == 0:
             if self.input_spectrum is None:
@@ -512,8 +494,6 @@ class Monochromator(XoppyWidget):
             Mono_Effect = [1] * len(energies)
 
 
-
-
         # from srxraylib.plot.gol import plot
         # plot(energies, Mono_Effect)
 
@@ -568,11 +548,9 @@ def List_Product(list):
 
 if __name__ == "__main__":
 
-
     from oasys.widgets.exchange import DataExchangeObject
 
 
-
     input_data_type = "POWER"
 
     if input_data_type == "POWER":
@@ -585,7 +563,7 @@ if __name__ == "__main__":
 
     elif input_data_type == "POWER3D":
         # create unulator_radiation xoppy exchange data
-        from orangecontrib.xoppy.util.xoppy_undulators import xoppy_calc_undulator_radiation
+        from xoppylib.sources.xoppy_undulators import xoppy_calc_undulator_radiation
 
         e, h, v, p, code = xoppy_calc_undulator_radiation(ELECTRONENERGY=6.04,ELECTRONENERGYSPREAD=0.001,ELECTRONCURRENT=0.2,\
                                            ELECTRONBEAMSIZEH=0.000395,ELECTRONBEAMSIZEV=9.9e-06,\
@@ -602,8 +580,6 @@ if __name__ == "__main__":
         received_data.add_content("xoppy_code", code)
 
 
-
-
     app = QApplication(sys.argv)
     w = Monochromator()
     w.acceptExchangeData(received_data)
